pub struct CleanOptions {
pub preserve_paragraphs: bool,
pub strip_markdown_artifacts: bool,
pub strip_invisible_chars: bool,
pub collapse_all_whitespace: bool,
}Expand description
Options for txt-cleaner operations.
Fields
preserve_paragraphs: boolWhen true, preserves paragraph structure by collapsing consecutive blank
lines to a single blank line (\n\n).
strip_markdown_artifacts: boolWhen true, remove common markdown/html artifacts from the edges of the text.
strip_invisible_chars: boolWhen true, remove invisible characters like BOM and zero-width spaces.
collapse_all_whitespace: boolWhen true, collapse all whitespace sequences to a single space.
Implementations
Sourceimpl CleanOptions
impl CleanOptions
Sourcepub fn builder() -> CleanBuilder
pub fn builder() -> CleanBuilder
Create a new builder for CleanOptions.